import { EventDefinition, HttpClient } from '@wix/sdk-types';
import { BulkCreateInfoSectionsOptions, BulkCreateInfoSectionsResponse, BulkDeleteInfoSectionsResponse, BulkGetOrCreateInfoSectionsOptions, BulkGetOrCreateInfoSectionsResponse, BulkUpdateInfoSectionsOptions, BulkUpdateInfoSectionsResponse, GetInfoSectionOptions, GetOrCreateInfoSectionOptions, GetOrCreateInfoSectionResponse, InfoSection, InfoSectionCreatedEnvelope, InfoSectionDeletedEnvelope, InfoSectionUpdatedEnvelope, InfoSectionsQueryBuilder, MaskedInfoSection, QueryInfoSectionsOptions, UpdateInfoSection, UpdateInfoSectionOptions } from './stores-catalog-v3-info-section-info-sections-v-3.universal.js';
export declare const __metadata: {
    PACKAGE_NAME: string;
};
export declare function createInfoSection(httpClient: HttpClient): CreateInfoSectionSignature;
interface CreateInfoSectionSignature {
    /**
     * Creates an info section.
     *
     * To assign the info section to a product, include the `infoSection.id` or `infoSection.uniqueName`
     * when [creating](https://dev.wix.com/docs/rest/business-solutions/stores/catalog-v3/products-v3/create-product) or
     * [updating](https://dev.wix.com/docs/rest/business-solutions/stores/catalog-v3/products-v3/update-product) a product.
     * @param - Info section to create.
     * @returns Created info section.
     */
    (infoSection: InfoSection): Promise<InfoSection>;
}
export declare function getInfoSection(httpClient: HttpClient): GetInfoSectionSignature;
interface GetInfoSectionSignature {
    /**
     * Retrieves an info section.
     * @param - Info section ID.
     * @returns Info section.
     */
    (infoSectionId: string, options?: GetInfoSectionOptions | undefined): Promise<InfoSection>;
}
export declare function getOrCreateInfoSection(httpClient: HttpClient): GetOrCreateInfoSectionSignature;
interface GetOrCreateInfoSectionSignature {
    /**
     * Retrieves an info section by ID or `uniqueName`, or creates an info section if one with the passed `uniqueName` doesn't exist.
     *
     * > **Note:** If an info section with the passed `uniqueName` doesn't exist, the `uniqueName` and `title` fields are required to create a new info section.
     */
    (options?: GetOrCreateInfoSectionOptions | undefined): Promise<GetOrCreateInfoSectionResponse>;
}
export declare function bulkGetOrCreateInfoSections(httpClient: HttpClient): BulkGetOrCreateInfoSectionsSignature;
interface BulkGetOrCreateInfoSectionsSignature {
    /**
     * Retrieves multiple info sections by ID or `uniqueName`, or creates multiple info sections if those with the passed `uniqueName` don't exist.
     *
     * > **Note:** If an info section with the passed `uniqueName` doesn't exist, the `uniqueName` and `title` fields are required to create a new info section.
     */
    (options?: BulkGetOrCreateInfoSectionsOptions | undefined): Promise<BulkGetOrCreateInfoSectionsResponse>;
}
export declare function updateInfoSection(httpClient: HttpClient): UpdateInfoSectionSignature;
interface UpdateInfoSectionSignature {
    /**
     * Updates an info section.
     *
     *
     * Each time the info section is updated, `revision` increments by 1.
     * The current `revision` must be passed when updating the info section.
     * This ensures you're working with the latest info section and prevents unintended overwrites.
     * @param - Info section ID.
     * @returns Updated info section.
     */
    (_id: string, infoSection: UpdateInfoSection, options?: UpdateInfoSectionOptions | undefined): Promise<InfoSection>;
}
export declare function deleteInfoSection(httpClient: HttpClient): DeleteInfoSectionSignature;
interface DeleteInfoSectionSignature {
    /**
     * Deletes an info section.
     *
     * > **Note:** Deleting an info section will also remove it from all products it is assigned to.
     * @param - Info section ID
     */
    (infoSectionId: string): Promise<void>;
}
export declare function queryInfoSections(httpClient: HttpClient): QueryInfoSectionsSignature;
interface QueryInfoSectionsSignature {
    /**
     * Retrieves a list of up to 100 info sections, given the provided filtering, sorting, and cursor paging.
     * Pass supported values to the `fields` array in the request to include those fields in the response.
     *
     *
     * Query Info Sections runs with these defaults, which you can override:
     *
     * - `createdDate` is sorted in `DESC` order
     * - `cursorPaging.limit` is `100`
     *
     * For field support for filters and sorting,
     * see [Info Sections: Supported Filters and Sorting](https://dev.wix.com/docs/rest/business-solutions/stores/catalog-v3/info-sections-v3/supported-filters-and-sorting).
     *
     * To learn about working with _Query_ endpoints, see
     * [API Query Language](https://dev.wix.com/docs/rest/articles/getting-started/api-query-language),
     * and [Sorting and Paging](https://dev.wix.com/docs/rest/articles/getting-started/sorting-and-paging).
     */
    (options?: QueryInfoSectionsOptions | undefined): InfoSectionsQueryBuilder;
}
export declare function bulkCreateInfoSections(httpClient: HttpClient): BulkCreateInfoSectionsSignature;
interface BulkCreateInfoSectionsSignature {
    /**
     * Creates multiple info sections.
     * @param - Info sections to create.
     */
    (infoSections: InfoSection[], options?: BulkCreateInfoSectionsOptions | undefined): Promise<BulkCreateInfoSectionsResponse>;
}
export declare function bulkUpdateInfoSections(httpClient: HttpClient): BulkUpdateInfoSectionsSignature;
interface BulkUpdateInfoSectionsSignature {
    /**
     * Updates multiple info sections.
     *
     * Each time an info section is updated, `revision` increments by 1.
     * The current `revision` must be passed when updating an info section.
     * This ensures you're working with the latest info section and prevents unintended overwrites.
     * @param - List of info sections to update.
     */
    (infoSections: MaskedInfoSection[], options?: BulkUpdateInfoSectionsOptions | undefined): Promise<BulkUpdateInfoSectionsResponse>;
}
export declare function bulkDeleteInfoSections(httpClient: HttpClient): BulkDeleteInfoSectionsSignature;
interface BulkDeleteInfoSectionsSignature {
    /**
     * Deletes multiple info sections.
     * @param - IDs of info sections to delete.
     */
    (infoSectionIds: string[]): Promise<BulkDeleteInfoSectionsResponse>;
}
export declare const onInfoSectionCreated: EventDefinition<InfoSectionCreatedEnvelope, "wix.stores.catalog.v3.info_section_created">;
export declare const onInfoSectionDeleted: EventDefinition<InfoSectionDeletedEnvelope, "wix.stores.catalog.v3.info_section_deleted">;
export declare const onInfoSectionUpdated: EventDefinition<InfoSectionUpdatedEnvelope, "wix.stores.catalog.v3.info_section_updated">;
export { ActionEvent, Alignment, AnchorData, App, AppEmbedData, AppEmbedDataAppDataOneOf, AppType, ApplicationError, AudioData, Background, BackgroundBackgroundOneOf, BackgroundType, BaseEventMetadata, BlockquoteData, BookingData, Border, BorderColors, BulkActionMetadata, BulkCreateInfoSectionsOptions, BulkCreateInfoSectionsRequest, BulkCreateInfoSectionsResponse, BulkDeleteInfoSectionsRequest, BulkDeleteInfoSectionsResponse, BulkGetOrCreateInfoSectionsOptions, BulkGetOrCreateInfoSectionsRequest, BulkGetOrCreateInfoSectionsResponse, BulkInfoSectionItemResult, BulkInfoSectionResult, BulkUpdateInfoSectionsOptions, BulkUpdateInfoSectionsRequest, BulkUpdateInfoSectionsResponse, BulletedListData, ButtonData, CaptionData, CellStyle, CodeBlockData, CollapsibleListData, ColorData, Colors, CreateInfoSectionRequest, CreateInfoSectionResponse, Crop, CursorPaging, CursorPagingMetadata, CursorQuery, CursorQueryPagingMethodOneOf, Cursors, CustomTag, Decoration, DecorationDataOneOf, DecorationType, DeleteInfoSectionRequest, DeleteInfoSectionResponse, Design, Dimensions, Direction, DividerData, DocumentStyle, DomainEvent, DomainEventBodyOneOf, EmbedData, Empty, EntityCreatedEvent, EntityDeletedEvent, EntityUpdatedEvent, EventData, EventMetadata, File, FileData, FileSource, FileSourceDataOneOf, FontSizeData, FontType, GIF, GIFData, GIFType, GalleryData, GalleryOptions, GetInfoSectionOptions, GetInfoSectionRequest, GetInfoSectionResponse, GetOrCreateInfoSectionOptions, GetOrCreateInfoSectionRequest, GetOrCreateInfoSectionResponse, Gradient, HTMLData, HTMLDataDataOneOf, HeadingData, Height, IdentificationData, IdentificationDataIdOneOf, Image, ImageData, ImageDataStyles, InfoSection, InfoSectionCreatedEnvelope, InfoSectionDeletedEnvelope, InfoSectionForGetOrCreate, InfoSectionUpdatedEnvelope, InfoSectionsQueryBuilder, InfoSectionsQueryResult, InitialExpandedItems, InvalidateCache, InvalidateCacheGetByOneOf, Item, ItemDataOneOf, ItemMetadata, ItemStyle, Layout, LayoutCellData, LayoutType, LineStyle, Link, LinkData, LinkDataOneOf, LinkPreviewData, LinkPreviewDataStyles, ListValue, MapData, MapSettings, MapType, MaskedInfoSection, Media, MentionData, MessageEnvelope, Metadata, Node, NodeDataOneOf, NodeStyle, NodeType, NullValue, Oembed, Option, OptionDesign, OptionLayout, OrderedListData, Orientation, PDFSettings, Page, ParagraphData, Permissions, PlaybackOptions, PluginContainerData, PluginContainerDataAlignment, PluginContainerDataWidth, PluginContainerDataWidthDataOneOf, Poll, PollData, PollDataLayout, PollDesign, PollLayout, PollLayoutDirection, PollLayoutType, Position, QueryInfoSectionsOptions, QueryInfoSectionsRequest, QueryInfoSectionsResponse, Rel, RequestedFields, RestoreInfo, RichContent, Settings, SortOrder, Sorting, Source, Spoiler, SpoilerData, Styles, StylesBorder, TableCellData, TableData, Target, TextAlignment, TextData, TextNodeStyle, TextStyle, Thumbnails, ThumbnailsAlignment, Type, URI, UpdateInfoSection, UpdateInfoSectionOptions, UpdateInfoSectionRequest, UpdateInfoSectionResponse, VerticalAlignment, Video, VideoData, ViewMode, ViewRole, VoteRole, WebhookIdentityType, Width, WidthType, } from './stores-catalog-v3-info-section-info-sections-v-3.universal.js';
