import { RequestOptionsFactory } from '@wix/sdk-types';
/**
 * Creates an info section.
 *
 * To assign the info section to a product, include the `infoSection.id` or `infoSection.uniqueName`
 * when [creating](https://dev.wix.com/docs/rest/business-solutions/stores/catalog-v3/products-v3/create-product) or
 * [updating](https://dev.wix.com/docs/rest/business-solutions/stores/catalog-v3/products-v3/update-product) a product.
 */
export declare function createInfoSection(payload: object): RequestOptionsFactory<any>;
/** Retrieves an info section. */
export declare function getInfoSection(payload: object): RequestOptionsFactory<any>;
/**
 * Retrieves an info section by ID or `uniqueName`, or creates an info section if one with the passed `uniqueName` doesn't exist.
 *
 * > **Note:** If an info section with the passed `uniqueName` doesn't exist, the `uniqueName` and `title` fields are required to create a new info section.
 */
export declare function getOrCreateInfoSection(payload: object): RequestOptionsFactory<any>;
/**
 * Retrieves multiple info sections by ID or `uniqueName`, or creates multiple info sections if those with the passed `uniqueName` don't exist.
 *
 * > **Note:** If an info section with the passed `uniqueName` doesn't exist, the `uniqueName` and `title` fields are required to create a new info section.
 */
export declare function bulkGetOrCreateInfoSections(payload: object): RequestOptionsFactory<any>;
/**
 * Updates an info section.
 *
 *
 * Each time the info section is updated, `revision` increments by 1.
 * The current `revision` must be passed when updating the info section.
 * This ensures you're working with the latest info section and prevents unintended overwrites.
 */
export declare function updateInfoSection(payload: object): RequestOptionsFactory<any>;
/**
 * Deletes an info section.
 *
 * > **Note:** Deleting an info section will also remove it from all products it is assigned to.
 */
export declare function deleteInfoSection(payload: object): RequestOptionsFactory<any>;
/**
 * Retrieves a list of up to 100 info sections, given the provided filtering, sorting, and cursor paging.
 * Pass supported values to the `fields` array in the request to include those fields in the response.
 *
 *
 * Query Info Sections runs with these defaults, which you can override:
 *
 * - `createdDate` is sorted in `DESC` order
 * - `cursorPaging.limit` is `100`
 *
 * For field support for filters and sorting,
 * see [Info Sections: Supported Filters and Sorting](https://dev.wix.com/docs/rest/business-solutions/stores/catalog-v3/info-sections-v3/supported-filters-and-sorting).
 *
 * To learn about working with _Query_ endpoints, see
 * [API Query Language](https://dev.wix.com/docs/rest/articles/getting-started/api-query-language),
 * and [Sorting and Paging](https://dev.wix.com/docs/rest/articles/getting-started/sorting-and-paging).
 */
export declare function queryInfoSections(payload: object): RequestOptionsFactory<any>;
/** Creates multiple info sections. */
export declare function bulkCreateInfoSections(payload: object): RequestOptionsFactory<any>;
/**
 * Updates multiple info sections.
 *
 * Each time an info section is updated, `revision` increments by 1.
 * The current `revision` must be passed when updating an info section.
 * This ensures you're working with the latest info section and prevents unintended overwrites.
 */
export declare function bulkUpdateInfoSections(payload: object): RequestOptionsFactory<any>;
/** Deletes multiple info sections. */
export declare function bulkDeleteInfoSections(payload: object): RequestOptionsFactory<any>;
